@@ -24,12 +24,14 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 // Qt
 #include <QApplication>
 #include <QUrl>
+#include <QImageWriter>
+#include <QMimeDatabase>
 
 // KDE
 #include <KFileDialog>
-#include <KGlobalSettings>
-#include <KImageIO>
-#include <KIO/NetAccess>
+#include <KColorScheme>
+#include <KIO/StatJob>
+#include <KJobWidgets>
 #include <KLocalizedString>
 #include <KMessageBox>
 #include <KStandardDirs>
@@ -69,8 +71,14 @@ struct GvCorePrivate
         KFileDialog dialog(url, QString(), mMainWindow);
         dialog.setOperationMode(KFileDialog::Saving);
         dialog.setSelection(url.fileName());
+
+        QStringList supportedMimetypes;
+        for (const QByteArray &mimeName : QImageWriter::supportedMimeTypes()) {
+            supportedMimetypes.append(QString::fromLocal8Bit(mimeName));
+        }
+
         dialog.setMimeFilter(
-            KImageIO::mimeTypes(KImageIO::Writing), // List
+            supportedMimetypes,
             MimeTypeUtils::urlMimeType(url)         // Default
         );
 
@@ -90,7 +98,7 @@ struct GvCorePrivate
                 continue;
             }
 
-            const QStringList typeList = KImageIO::typeForMime(mimeType);
+            const QStringList typeList = QMimeDatabase().mimeTypeForName(mimeType).suffixes();
             if (typeList.count() > 0) {
                 *format = typeList[0].toAscii();
                 break;
@@ -113,7 +121,8 @@ struct GvCorePrivate
         QColor fgColor = value > 128 ? Qt::black : Qt::white;
 
         // Normal
-        mPalettes[GvCore::NormalPalette] = KGlobalSettings::createApplicationPalette();
+        KSharedConfigPtr config = KSharedConfig::openConfig();
+        mPalettes[GvCore::NormalPalette] = KColorScheme::createApplicationPalette(config);
 
         pal = mPalettes[GvCore::NormalPalette];
         pal.setColor(QPalette::Base, QColor::fromHsv(0, 0, value));
@@ -121,7 +130,6 @@ struct GvCorePrivate
         mPalettes[GvCore::NormalViewPalette] = pal;
 
         // Fullscreen
-        KSharedConfigPtr config;
         QString name = GwenviewConfig::fullScreenColorScheme();
         if (name.isEmpty()) {
             // Default color scheme
@@ -134,7 +142,7 @@ struct GvCorePrivate
             // Standard KDE color scheme
             config = KSharedConfig::openConfig(QString("color-schemes/%1.colors").arg(name), KConfig::FullConfig, QStandardPaths::DataLocation);
         }
-        mPalettes[GvCore::FullScreenPalette] = KGlobalSettings::createApplicationPalette(config);
+        mPalettes[GvCore::FullScreenPalette] = KColorScheme::createApplicationPalette(config);
 
         pal = mPalettes[GvCore::FullScreenPalette];
         QString path = KStandardDirs::locate("data", "gwenview/images/background.png");
@@ -225,8 +233,8 @@ void GvCore::save(const QUrl &url)
 {
     Document::Ptr doc = DocumentFactory::instance()->load(url);
     QByteArray format = doc->format();
-    const QStringList availableTypes = KImageIO::types(KImageIO::Writing);
-    if (availableTypes.contains(QString(format))) {
+    const QByteArrayList availableTypes = QImageWriter::supportedImageFormats();
+    if (availableTypes.contains(format)) {
         DocumentJob* job = doc->save(url, format);
         connect(job, SIGNAL(result(KJob*)), SLOT(slotSaveResult(KJob*)));
     } else {
@@ -255,7 +263,9 @@ void GvCore::saveAs(const QUrl &url)
     }
 
     // Check for overwrite
-    if (KIO::NetAccess::exists(saveAsUrl, KIO::NetAccess::DestinationSide, d->mMainWindow)) {
+    KIO::StatJob *statJob = KIO::stat(saveAsUrl, KIO::StatJob::DestinationSide, 0);
+    KJobWidgets::setWindow(statJob, d->mMainWindow);
+    if (statJob->exec()) {
         int answer = KMessageBox::warningContinueCancel(
                          d->mMainWindow,
                          xi18nc("@info",
